% function [z3,k] = muller(z0,z1,z2,p,maxit,tol)
% 
%   Finds a polynomial root given the initial guesses z0,z1,z2 using
%   a quadratic mode (Muller's method). This method allows convergence
%   to a complex root even if the z0,z1,z2 are real.
%
%  Inputs
%   z0,z1,z2  initial guesses
%   p         vector of polynomial coefficients, from highest to lowest degree
%   maxit     maximum number of iteration
%   tol       tolerance
%
%  Outputs
%   z3        approximation of the root
%   k         number of iterations
function [z3,k] = muller(z0,z1,z2,p,maxit,tol)

% TO BE COMPLETED: You need to use your own version of Horner's method

